Module device

Module device 

Android device detection and management.

Structs

AndroidDevice
Represents an Android device (physical or emulator).
AndroidEmulator
Android emulator (AVD) that needs to be launched.

Traits

AndroidAbiProvider
Provides the Android ABI required to build/package for a target.

Functions

describe
Describe UI elements on the screen.
emulator_avd_name
Resolve the AVD name for a running emulator device.
emulator_avd_name_with_adb
Query the AVD name for a running emulator device via adb emu avd name.
screenshot
Capture a screenshot from an Android device.
screenshot_bytes
Capture a screenshot from an Android device and return the raw PNG bytes.
swipe
Perform a swipe gesture on an Android device.
tap
Perform a tap gesture on an Android device at the specified coordinates.
text
Input text on an Android device.