Module platform

Module platform 

Android platform configuration. Android platform build and package utilities.

This module provides utility functions for building and packaging Android apps. These functions are used by AndroidBackend to implement the Backend trait.

Structs

AndroidPlatform
Represents an Android platform for a specific ABI.
UnsupportedAndroidAbi
Error returned when parsing an unsupported Android ABI string.

Enums

AndroidAbi
Represents an Android platform for a specific architecture.

Constants

ALL_ABIS
All supported Android ABIs.

Functions

clean_android
Clean Gradle build artifacts for Android.
is_android_platform
Check if a platform is supported by the Android backend.