pub const fn is_android_platform(platform: TargetPlatform) -> boolExpand description
Check if a platform is supported by the Android backend.
pub const fn is_android_platform(platform: TargetPlatform) -> boolCheck if a platform is supported by the Android backend.