Module platform

Module platform 

Apple platform build and package utilities.

This module provides utility functions for building and packaging Apple apps. These functions are used by AppleBackend to implement the Backend trait.

Functions

apple_deployment_target
Resolve the deployment-target environment variable an Apple build must carry.
build_rust_lib
Build Rust library for an Apple platform.
clean_apple
Clean Xcode build artifacts for an Apple platform.
is_apple_platform
Check if a platform is supported by the Apple backend.
package_apple
Package an Apple app using xcodebuild.