pub const fn is_apple_platform(platform: TargetPlatform) -> boolExpand description
Check if a platform is supported by the Apple backend.
pub const fn is_apple_platform(platform: TargetPlatform) -> boolCheck if a platform is supported by the Apple backend.