pub struct RustBuild { /* private fields */ }Expand description
Represents a Rust build for a specific target triple.
Implementations
Sourceimpl RustBuild
impl RustBuild
Sourcepub fn new(path: impl AsRef<Path>, triple: Triple, hot_reload: bool) -> Self
pub fn new(path: impl AsRef<Path>, triple: Triple, hot_reload: bool) -> Self
Create a new rust build for the given path and target triple.
Sourcepub async fn dev_build(&self) -> Result<PathBuf, RustBuildError>
pub async fn dev_build(&self) -> Result<PathBuf, RustBuildError>
Build rust library in development mode.
Will produce debug symbols and less optimizations for faster builds.
Return the path to the built library.
Errors
RustBuildError::FailToExecuteCargoBuild: If there was an error executing the cargo build command.RustBuildError::FailToBuildRustLibrary: If there was an error building the Rust library.
Sourcepub async fn release_build(&self) -> Result<PathBuf, RustBuildError>
pub async fn release_build(&self) -> Result<PathBuf, RustBuildError>
Build rust library in release mode.
Return the directory path containing the built library.
Errors
RustBuildError::FailToExecuteCargoBuild: If there was an error executing the cargo build command.RustBuildError::FailToBuildRustLibrary: If there was an error building the Rust library.
Sourcepub async fn build_lib(&self, release: bool) -> Result<PathBuf, RustBuildError>
pub async fn build_lib(&self, release: bool) -> Result<PathBuf, RustBuildError>
Build a library with the specified crate type.
Return the directory path containing the built library.
Errors
RustBuildError::FailToExecuteCargoBuild: If there was an error executing the cargo build command.RustBuildError::FailToBuildRustLibrary: If there was an error building the Rust library.