Module capture

Module capture 

Screen capture utilities for devices.

Provides unified screenshot capture across iOS simulators and Android devices.

Enums

DevicePlatform
The platform type of a device based on its identifier.

Functions

detect_platform
Detect the platform of a device from its identifier.
generate_screenshot_filename
Generate a default output filename for a screenshot.
screenshot
Capture a screenshot from a device.
verify_device
Verify that a device exists and return its platform.