Module hot_reload

Module hot_reload 

Hot reload server for WaterUI CLI.

Provides a WebSocket server that broadcasts dylib updates to connected apps.

Structs

BuildManager
Manages hot reload builds with debouncing and cancellation.
HotReloadServer
Hot reload server that broadcasts dylib updates to connected apps.

Enums

BroadcastMessage
Message types that can be broadcast to connected clients.
FailToLaunch
Errors that can occur when launching the hot reload server.

Constants

DEBOUNCE_DURATION
Debounce duration for file changes before triggering a rebuild.
DEFAULT_PORT
Default starting port for hot reload server.
PORT_RETRY_COUNT
Number of ports to try before giving up.