Module device

Module device 

Device management and application running utilities for WaterUI CLI.

Structs

Artifact
Represents a build artifact to be run on a device
RunOptions
Options for running an application on a device
Running
Represents a running application on a device.

Enums

DeviceEvent
Events emitted by a running application on a device
DeviceKind
Represents the kind of device
DeviceState
Represents the state of a device
FailToRun
Errors that can occur when running an application on a device
LogLevel
Minimum log level for streaming device logs.

Traits

Device
Trait representing a device (e.g., emulator, simulator, physical device)