pub enum DeviceEvent {
Started,
Stopped,
Stdout {
message: String,
},
Stderr {
message: String,
},
Log {
level: Level,
message: String,
},
Exited,
Crashed(String),
}Expand description
Events emitted by a running application on a device
Variants
Started
Application has started
Stopped
Application has stopped by CLI
Stdout
Standard output from the application
Stderr
Standard error from the application
Log
Standard log from the application
Exited
Unexpected exit of the application, may triggered by user quitting
Crashed(String)
Application crashed with error message