pub struct ApplicationExit { /* private fields */ }Expand description
A clean application exit observed by the runner.
Implementations
Sourceimpl ApplicationExit
impl ApplicationExit
Sourcepub const fn completed() -> Self
pub const fn completed() -> Self
The application process finished with a successful process status.
Sourcepub const fn user_closed() -> Self
pub const fn user_closed() -> Self
A GUI application window or process closed without crash evidence.
Sourcepub const fn terminal_message(self) -> &'static str
pub const fn terminal_message(self) -> &'static str
Human-readable message for terminal status output.
Sourcepub const fn reason(self) -> ApplicationExitReason
pub const fn reason(self) -> ApplicationExitReason
Return the classified clean-exit reason.