pub const fn is_esp32_platform(platform: TargetPlatform) -> boolExpand description
Check if a platform is supported by the ESP32 backend.
pub const fn is_esp32_platform(platform: TargetPlatform) -> boolCheck if a platform is supported by the ESP32 backend.