Module framework

Module framework 

Framework channel resolution and persisted dependency selection.

Structs

ExperimentalPackage
A scaffold package a channel withholds.
ResolvedFramework
The persisted framework and backend selection used without channel re-resolution.

Enums

FrameworkChannel
A framework distribution channel, independent of the Rust toolchain.