pub async fn launch_inspector_session(
project_path: &Path,
platform: InspectorPlatform,
options: InspectorLaunchOptions,
progress: Option<BuildProgress>,
) -> Result<InspectorSession>Expand description
Launch (or relaunch) an inspector support app.
Errors
Returns an error if the support project cannot be prepared or the inspector app fails to launch.