Module package_output

Module package_output 

Moving packaged artifacts into a project’s output directory.

Functions

place_in_project
Move a packaged artifact out of the build cache into the project’s target/package/ directory and return the artifact at its new path.