Module preview

Module preview 

Preview system for rendering and capturing WaterUI views.

This module provides infrastructure for the water preview command:

  • app_client: TCP client for communicating with the preview support app
  • protocol: Message definitions for preview support app communication
  • inputs: Content fingerprinting for preview build caching
  • launcher: Preview support app lifecycle management
  • request: Preview argument resolution shared by water preview and the water mcp preview tool

Re-exports

pub use protocol::PreviewPlatform;
pub use request::CliHydrolysisPreviewTheme;
pub use request::CliPreviewBackend;
pub use request::CliPreviewPlatform;
pub use request::PreviewRequest;
pub use request::PreviewTarget;

Modules

protocol
Preview command protocol types.
request
Shared preview request resolution for water preview and the MCP preview tool.

Structs

HydrolysisPreviewRequest
Common inputs for driving the managed Hydrolysis preview backend.
HydrolysisPreviewScenario
Interactive capture scenario for Hydrolysis preview.
HydrolysisPreviewScenarioEvent
One input event in a preview scenario timeline.
PreviewAppClient
TCP client for the preview support app.
PreviewSession
A preview session that manages the preview app and TCP connection.
Size
Frame size for rendering.

Enums

HydrolysisPreviewEventKind
Event kind in a preview scenario.
HydrolysisPreviewPointerButton
Pointer button identifier for scenario events.
HydrolysisPreviewSource
Source used to produce a Hydrolysis preview view.
HydrolysisPreviewTheme
Theme package selected for Hydrolysis preview rendering.
PreviewProbe
What probing one or more candidate preview apps produced.

Functions

launch_preview_session
Launch a preview session for the given platform.
render_preview_with_hydrolysis
Render a preview via the managed Hydrolysis backend binary.
test_preview_with_hydrolysis
Run a semantic preview test session via the managed Hydrolysis backend binary.