check_toolchain_for_backend

Function check_toolchain_for_backend 

pub async fn check_toolchain_for_backend(
    platform: CliPreviewPlatform,
    backend: CliPreviewBackend,
) -> Result<()>
Check the host toolchain required by the resolved backend.

Errors

Returns an error if a required toolchain component is missing.