parse_frame

Function parse_frame 

pub fn parse_frame(s: &str) -> Result<(f32, f32)>
Parse frame size from a WIDTHxHEIGHT string.

Errors

Returns an error if the format is wrong or a dimension is not a positive finite number.