resolve_preview_backend

Function resolve_preview_backend 

pub fn resolve_preview_backend(
    platform: CliPreviewPlatform,
    backend_override: Option<CliPreviewBackend>,
) -> Result<CliPreviewBackend>
Resolve the rendering backend for a platform, applying the override when given.

Errors

Returns an error if the backend does not support the platform.