resolve_preview_target

Function resolve_preview_target 

pub fn resolve_preview_target(
    crate_name: &str,
    target: &str,
    force_expression: bool,
) -> PreviewTarget
Resolve the preview target: expr forces expression mode, and a target that is not a Rust path is treated as an expression either way.