pub struct PreviewSession {
pub client: PreviewAppClient,
pub platform: PreviewPlatform,
/* private fields */
}Expand description
A preview session that manages the preview app and TCP connection.
Fields
client: PreviewAppClientTCP client to the preview app.
platform: PreviewPlatformCurrent platform.
Implementations
Sourceimpl PreviewSession
impl PreviewSession
Sourcepub async fn build_dylib(&mut self, project_path: &Path) -> Result<BuiltDylib>
pub async fn build_dylib(&mut self, project_path: &Path) -> Result<BuiltDylib>
Build the user’s project as a dylib.
Errors
Returns an error if the project cannot be opened, rebuilt, or fingerprinted.
Sourcepub async fn render(
&mut self,
dylib: &BuiltDylib,
symbol: &str,
width: f32,
height: f32,
) -> Result<Vec<u8>>
pub async fn render( &mut self, dylib: &BuiltDylib, symbol: &str, width: f32, height: f32, ) -> Result<Vec<u8>>
Render a preview and return PNG bytes.
Errors
Returns an error if the preview app rejects the render or the transport fails.