Module project

Module project 

Project management and build utilities for WaterUI CLI.

Structs

AppConfig
App-specific configuration in Water.toml.
AppCrates
Crate name overrides for app mode.
BrowserRuntimePlan
Browser engines that must be staged for one resolved application graph.
CreateOptions
Options for creating a new WaterUI project.
Manifest
Configuration for a WaterUI project persisted to Water.toml.
Package
[package] section in Water.toml.
PermissionEntry
Permission entry for playground projects.
Project
Represents a WaterUI project with its manifest and crate information.
UnsupportedWebViewBackend
Error returned for an unsupported WebView engine/platform/backend combination.
WebScaffold
How create/init wires a declared web frontend into the scaffold.

Enums

FailToCreateProject
Errors that can occur when creating a new WaterUI project.
FailToOpenManifest
Errors that can occur when opening a Water.toml manifest file.
FailToOpenProject
Errors that can occur when opening a WaterUI project.
FailToSaveManifest
Errors that can occur when saving a Water.toml manifest file.
PackageType
Package type indicating what kind of project this is.
ResolvedWebViewBackend
The engine that draws this application’s standard WebView.

Functions

read_project_crate_name
Reads the package.name of a project’s Cargo.toml — the crate name the generated backends and preview symbols build on.