pub enum FailToOpenManifest {
ReadError(Error),
InvalidManifest(Error),
NotFound,
}Expand description
Errors that can occur when opening a Water.toml manifest file.
Variants
ReadError(Error)
Failed to read the manifest file from the filesystem.
InvalidManifest(Error)
The manifest file is invalid or malformed.
NotFound
The manifest file was not found at the specified path.