pub struct Manifest {
pub package: Package,
pub backends: Backends,
pub waterui_path: Option<String>,
pub permissions: HashMap<String, PermissionEntry>,
}Expand description
Configuration for a WaterUI project persisted to Water.toml.
Fields
package: PackagePackage information.
backends: BackendsBackend configurations for various platforms.
waterui_path: Option<String>Path to local WaterUI repository for dev mode.
When set, all backends will use this path instead of the published versions.
permissions: HashMap<String, PermissionEntry>Permission configuration for playground projects.
Implementations
Sourceimpl Manifest
impl Manifest
Sourcepub async fn open(path: impl AsRef<Path>) -> Result<Self, FailToOpenManifest>
pub async fn open(path: impl AsRef<Path>) -> Result<Self, FailToOpenManifest>
Open and parse a Water.toml manifest file from the specified path.
Errors
FailToOpenManifest::ReadError: If there was an error reading the file.FailToOpenManifest::InvalidManifest: If the file contents are not valid TOML.FailToOpenManifest::NotFound: If the file does not exist at the specified path.