check

Function check 

pub async fn check(host: &Host) -> Result<CheckOutcome>
water update --check: report the newest release without installing it.

The release source comes from the install receipt when one covers this binary and from this repository’s GitHub releases otherwise.

Errors

Returns an error when the install source cannot be determined or the release query fails.