Module linux

Module linux 

Linux system package toolchain checks.

Structs

LinuxSystemPackagesInstallation
Installation plan for missing Linux system packages.
LinuxSystemToolchain
Linux system dependencies required by waterui desktop/media builds.

Enums

FailToInstallLinuxSystemPackages
Errors that can occur during Linux package installation.
LinuxPackageManagerError
Errors from Linux package-manager operations.

Functions

gtk4_pkg_config_repair_installation
Build an installation plan that repairs missing GTK pkg-config probes.
has_supported_package_manager
Returns true when a supported Linux package manager is available.
install_java_jdk
Install a JDK package using the detected Linux package manager.
install_named_packages
Install named packages with the detected Linux package manager.