install_named_packages

Function install_named_packages 

pub async fn install_named_packages(
    host: &Host,
    packages: &[&'static str],
) -> Result<(), LinuxPackageManagerError>
Install named packages with the detected Linux package manager.

Errors

Returns an error when no supported package manager is available, or when installation fails.