pub fn cmake() -> Option<ManagedTool>Expand description
cmake for a Windows host without a package manager, from the pinned
Kitware release zip.
pub fn cmake() -> Option<ManagedTool>cmake for a Windows host without a package manager, from the pinned
Kitware release zip.