Module toolchain_checks

Module toolchain_checks 

Shared toolchain checks for the terminal commands and the water mcp preview tool.

Functions

check_android_build_or_package
Verify the Android toolchain covers building and packaging for all ABIs.
check_android_build_or_package_for_abis
Verify the Android toolchain covers building and packaging for required_abis.
check_android_run
Verify the Android toolchain covers running an app (adds adb to the build requirements).
check_apple
Verify Xcode and the requested Apple SDK are installed.
check_gtk4
Verify the GTK4 toolchain is installed.
check_hydrolysis
Verify the host toolchain components Hydrolysis builds need.
check_web
Verify the web toolchain is installed.
check_winui
Verify the WinUI toolchain is installed.