check_android_run

Function check_android_run 

pub async fn check_android_run(host: &Host) -> Result<()>
Verify the Android toolchain covers running an app (adds adb to the build requirements).

Errors

Returns an error describing any missing toolchain component and the water doctor --fix remedy.