Module utils

Module utils 

Utility functions for the CLI.

Enums

CommandError
An external command could not be executed or exited unsuccessfully.
VersionParseError
A version string parse_semver_version could not normalize.

Functions

copy_file
Async file copy using reflink when available, falling back to regular copy.
parse_semver_version
Parse a version that may omit the minor and/or patch components.
sccache_install_hint
Returns a platform-appropriate installation hint for sccache.
sccache_upgrade_hint
Returns a platform-appropriate upgrade hint for an already-installed sccache that is too old — install is a no-op on an existing package.
set_std_output
Enable or disable standard output for command executions.