pub struct BuildCacheGcSummary {
pub scanned_entries: usize,
pub removed_entries: usize,
}Expand description
Summary of one managed build-cache garbage-collection pass.
Fields
scanned_entries: usizeNumber of managed cache entries inspected, excluding the active project cache.
removed_entries: usizeNumber of stale managed cache entries removed during this pass.