dev_script

Function dev_script 

pub fn dev_script(root: &Path) -> Result<String>
The script that starts the frontend’s dev server: the first of dev, serve, start declared in the project’s package.json.

Errors

Fails when package.json cannot be read or parsed, or declares none of the known dev scripts.