pub fn lockfile_package_manager(entries: &[String]) -> Option<PackageManager>Expand description
The package manager a lockfile implies, used as the prompt’s initial value.
pub fn lockfile_package_manager(entries: &[String]) -> Option<PackageManager>The package manager a lockfile implies, used as the prompt’s initial value.