Module device

Module device 

WinUI device - re-exports Local device.

WinUI apps run directly on the host machine, which is handled by the shared Local device implementation in crate::device.

Structs

Local
Local device representing the current machine.