Module platform

Module platform 

WinUI platform build and package utilities.

This module provides utility functions for building and packaging WinUI apps. These functions are used by WinUiBackend to implement the Backend trait.

Functions

build_winui
Build WinUI binary for the host platform.
clean_winui
Clean Cargo build artifacts for WinUI.
is_winui_platform
Check if a platform is supported by the WinUI backend.
package_winui
Package a WinUI app (locate the built binary and stage its resources).