pub const fn is_winui_platform(platform: TargetPlatform) -> boolExpand description
Check if a platform is supported by the WinUI backend.
pub const fn is_winui_platform(platform: TargetPlatform) -> boolCheck if a platform is supported by the WinUI backend.