package_winui

Function package_winui 

pub async fn package_winui(
    project: &Project,
    options: PackageOptions,
) -> Result<Artifact>
Package a WinUI app (locate the built binary and stage its resources).

Errors

Returns an error if the host is unsupported, assets cannot be staged, or the built binary is missing.