Android device detection and management.
Structs
- Android
Device - Represents an Android device (physical or emulator).
- Android
Emulator - Android emulator (AVD) that needs to be launched.
Traits
- Android
AbiProvider - Provides the Android ABI required to build/package for a target.
Functions
- describe
- Describe UI elements on the screen.
- emulator_
avd_ name - Resolve the AVD name for a running emulator device.
- emulator_
avd_ name_ with_ adb - Query the AVD name for a running emulator device via
adb emu avd name. - screenshot
- Capture a screenshot from an Android device.
- screenshot_
bytes - Capture a screenshot from an Android device and return the raw PNG bytes.
- swipe
- Perform a swipe gesture on an Android device.
- tap
- Perform a tap gesture on an Android device at the specified coordinates.
- text
- Input text on an Android device.