Android platform configuration. Android platform build and package utilities.
This module provides utility functions for building and packaging Android apps.
These functions are used by AndroidBackend to implement the Backend trait.
Structs
- Android
Platform - Represents an Android platform for a specific ABI.
- Unsupported
Android Abi - Error returned when parsing an unsupported Android ABI string.
Enums
- Android
Abi - Represents an Android platform for a specific architecture.
Constants
- ALL_
ABIS - All supported Android ABIs.
Functions
- clean_
android - Clean Gradle build artifacts for Android.
- is_
android_ platform - Check if a platform is supported by the Android backend.