pub struct AndroidPlatform { /* private fields */ }Expand description
Represents an Android platform for a specific architecture.
Implementations
Sourceimpl AndroidPlatform
impl AndroidPlatform
Sourcepub const fn new(architecture: Architecture) -> Self
pub const fn new(architecture: Architecture) -> Self
Create a new Android platform with the specified architecture.
Sourceimpl AndroidPlatform
impl AndroidPlatform
Sourcepub async fn clean_jni_libs(project: &Project) -> Result<()>
pub async fn clean_jni_libs(project: &Project) -> Result<()>
Clean all jniLibs directories to remove stale libraries from previous builds.
Errors
Returns an error if the directory cannot be removed.
Sourcepub async fn package_with_abis(
project: &Project,
options: PackageOptions,
abis: &[&str],
) -> Result<Artifact>
pub async fn package_with_abis( project: &Project, options: PackageOptions, abis: &[&str], ) -> Result<Artifact>