Apple platform build and package utilities.
This module provides utility functions for building and packaging Apple apps.
These functions are used by AppleBackend to implement the Backend trait.
Functions
- apple_
deployment_ target - Resolve the deployment-target environment variable an Apple build must carry.
- build_
rust_ lib - Build Rust library for an Apple platform.
- clean_
apple - Clean Xcode build artifacts for an Apple platform.
- is_
apple_ platform - Check if a platform is supported by the Apple backend.
- package_
apple - Package an Apple app using xcodebuild.