Build system
Structs
- Build
Options - Options for building Rust libraries.
- Rust
Build - Represents a Rust build for a specific target triple.
- Rust
Dynamic Libraries - Dynamic Rust libraries required by a shared-runtime development build.
Enums
- Build
Profile - The optimization/debug-info trade-off a Cargo build selects.
- Rust
Build Error - Errors that can occur during the Rust build process.
- Rust
Linkage - Selects how Rust dependencies are linked into a native application.
Functions
- configure_
generated_ crate_ compilation - Configure a Cargo invocation that compiles one of
WaterUI’s generated crates. - lib_
extension_ for_ triple - Get the dynamic library extension for a target triple.
- rust_
target_ libdir - Resolve the Rust standard-library directory for a target triple.