pub async fn rust_target_libdir(
triple: &Triple,
toolchain: &str,
) -> Result<PathBuf>Expand description
Resolve the Rust standard-library directory for a target triple under
toolchain, the rustup toolchain the libraries were built with.
Errors
Returns an error if rustc cannot resolve an existing target library directory.