pub async fn verify_device( host: &Host, device_id: &str, ) -> Result<DevicePlatform>
Verify that a device exists and return its platform.
Returns an error if the device cannot be found on the inferred platform.