Device management and application running utilities for WaterUI CLI.
Structs
- Artifact
- Represents a build artifact to be run on a device
- RunOptions
- Options for running an application on a device
- Running
- Represents a running application on a device.
Enums
- Device
Event - Events emitted by a running application on a device
- Device
Kind - Represents the kind of device
- Device
State - Represents the state of a device
- Fail
ToRun - Errors that can occur when running an application on a device
- LogLevel
- Minimum log level for streaming device logs.
Traits
- Device
- Trait representing a device (e.g., emulator, simulator, physical device)