Module framework

Module framework 

Framework channel resolution and persisted dependency selection.

Structs

ResolvedFramework
The persisted framework and backend selection used without channel re-resolution.

Enums

FrameworkChannel
A framework distribution channel, independent of the Rust toolchain.