GTK4 platform build and package utilities.
This module provides utility functions for building and packaging GTK4 apps.
These functions are used by Gtk4Backend to implement the Backend trait.
Functions
- build_
gtk4 - Build GTK4 binary for the host platform.
- clean_
gtk4 - Clean Cargo build artifacts for GTK4.
- is_
gtk4_ platform - Check if a platform is supported by the GTK4 backend.
- package_
gtk4 - Package a GTK4 app (locate the built binary).