pub async fn built_hydrolysis_binary_path(
project: &Project,
platform: TargetPlatform,
profile: &str,
linkage: RustLinkage,
) -> Result<PathBuf>Expand description
Resolve the built hydrolysis backend binary path for the given profile.
Errors
Returns an error if neither the canonical nor underscored backend binary can be found.