Moving packaged artifacts into a project’s output directory.
Functions
- place_
in_ project - Move a packaged artifact out of the build cache into the project’s
target/package/directory and return the artifact at its new path.
Moving packaged artifacts into a project’s output directory.
target/package/ directory and return the artifact at its new path.