Preview system for rendering and capturing WaterUI views.
This module provides infrastructure for the water preview command:
app_client: TCP client for communicating with the preview support appprotocol: Message definitions for preview support app communicationinputs: Content fingerprinting for preview build cachinglauncher: Preview support app lifecycle managementrequest: Preview argument resolution shared bywater previewand thewater mcppreviewtool
Re-exports
pub use protocol::PreviewPlatform;pub use request::CliHydrolysisPreviewTheme;pub use request::CliPreviewBackend;pub use request::CliPreviewPlatform;pub use request::PreviewRequest;pub use request::PreviewTarget;
Modules
- protocol
- Preview command protocol types.
- request
- Shared preview request resolution for
water previewand the MCPpreviewtool.
Structs
- Hydrolysis
Preview Request - Common inputs for driving the managed Hydrolysis preview backend.
- Hydrolysis
Preview Scenario - Interactive capture scenario for Hydrolysis preview.
- Hydrolysis
Preview Scenario Event - One input event in a preview scenario timeline.
- Preview
AppClient - TCP client for the preview support app.
- Preview
Session - A preview session that manages the preview app and TCP connection.
- Size
- Frame size for rendering.
Enums
- Hydrolysis
Preview Event Kind - Event kind in a preview scenario.
- Hydrolysis
Preview Pointer Button - Pointer button identifier for scenario events.
- Hydrolysis
Preview Source - Source used to produce a Hydrolysis preview view.
- Hydrolysis
Preview Theme - Theme package selected for Hydrolysis preview rendering.
- Preview
Probe - What probing one or more candidate preview apps produced.
Functions
- launch_
preview_ session - Launch a preview session for the given platform.
- render_
preview_ with_ hydrolysis - Render a preview via the managed Hydrolysis backend binary.
- test_
preview_ with_ hydrolysis - Run a semantic preview test session via the managed Hydrolysis backend binary.