pub async fn launch_preview_session(
project_path: &Path,
platform: PreviewPlatform,
sccache_path: Option<PathBuf>,
progress: Option<BuildProgress>,
) -> Result<PreviewSession>Expand description
Launch a preview session for the given platform.
This will:
- Try to connect to an existing preview app via TCP
- If not found, scaffold and launch the preview app
- Wait for TCP connection
Arguments
platform- Target platform for previewsccache_path- Optional path to sccache for compilation caching
Errors
Returns an error if the preview app cannot be launched or connected.