pub fn resolve_preview_backend(
platform: CliPreviewPlatform,
backend_override: Option<CliPreviewBackend>,
) -> Result<CliPreviewBackend>Expand description
Resolve the rendering backend for a platform, applying the override when given.
Errors
Returns an error if the backend does not support the platform.