Shared toolchain checks for the terminal commands and the water mcp
preview tool.
Functions
- check_
android_ build_ or_ package - Verify the Android toolchain covers building and packaging for all ABIs.
- check_
android_ build_ or_ package_ for_ abis - Verify the Android toolchain covers building and packaging for
required_abis. - check_
android_ run - Verify the Android toolchain covers running an app (adds
adbto the build requirements). - check_
apple - Verify Xcode and the requested Apple SDK are installed.
- check_
gtk4 - Verify the GTK4 toolchain is installed.
- check_
hydrolysis - Verify the host toolchain components Hydrolysis builds need.
- check_
web - Verify the web toolchain is installed.
- check_
winui - Verify the
WinUItoolchain is installed.