pub async fn check_android_run(host: &Host) -> Result<()>Expand description
Verify the Android toolchain covers running an app (adds adb to the build requirements).
Errors
Returns an error describing any missing toolchain component and the water doctor --fix remedy.