Utility functions for the CLI.
Enums
- Command
Error - An external command could not be executed or exited unsuccessfully.
- Version
Parse Error - A version string
parse_semver_versioncould not normalize.
Functions
- copy_
file - Async file copy using reflink when available, falling back to regular copy.
- parse_
semver_ version - Parse a version that may omit the minor and/or patch components.
- sccache_
install_ hint - Returns a platform-appropriate installation hint for sccache.
- sccache_
upgrade_ hint - Returns a platform-appropriate upgrade hint for an already-installed
sccache that is too old —
installis a no-op on an existing package. - set_
std_ output - Enable or disable standard output for command executions.