pub async fn build_cache_root() -> Result<PathBuf>
Return the global managed build-cache root at ~/.water/build_cache.
~/.water/build_cache
Returns an error if the Water config cannot be loaded or the cache root cannot be created.