pub async fn project_build_cache_dir(project_root: &Path) -> Result<PathBuf>Expand description
Return the managed build-cache directory for a project.
Errors
Returns an error if the project root cannot be canonicalized or the global cache root cannot be resolved.